import type { AspectMain } from '@teambit/aspect';
import { AspectDefinition } from '@teambit/aspect-loader';
import { CacheMain } from '@teambit/cache';
import { CLIMain } from '@teambit/cli';
import type { ComponentMain } from '@teambit/component';
import { ExpressMain } from '@teambit/express';
import type { GraphqlMain } from '@teambit/graphql';
import { SlotRegistry } from '@teambit/harmony';
import { Logger, LoggerMain } from '@teambit/logger';
import { UIRoot } from './ui-root';
import { UIServer } from './ui-server';
export declare type UIDeps = [CLIMain, GraphqlMain, ExpressMain, ComponentMain, CacheMain, LoggerMain, AspectMain];
export declare type UIRootRegistry = SlotRegistry<UIRoot>;
export declare type OnStart = () => void;
export declare type OnStartSlot = SlotRegistry<OnStart>;
export declare type UIConfig = {
    /**
     * port for the UI root to use.
     */
    port?: number;
    /**
     * port range for the UI root to use.
     */
    portRange: [number, number];
    /**
     * host for the UI root
     */
    host: string;
};
export declare type RuntimeOptions = {
    /**
     * name of the UI root to load.
     */
    uiRootName?: string;
    /**
     * component selector pattern to load.
     */
    pattern?: string;
    /**
     * determine whether to start a dev server (defaults to false).
     */
    dev?: boolean;
    /**
     * port of the config.
     */
    port?: number;
    /**
     * determine whether to rebuild the UI before start.
     */
    rebuild?: boolean;
};
export declare class UiMain {
    private config;
    /**
     * graphql extension.
     */
    private graphql;
    /**
     * slot registry of ui roots.
     */
    private uiRootSlot;
    /**
     * express extension.
     */
    private express;
    /**
     * on start slot
     */
    private onStartSlot;
    /**
     * component extension.
     */
    private componentExtension;
    /**
     * ui logger instance.
     */
    private cache;
    /**
     * ui logger instance.
     */
    private logger;
    constructor(config: UIConfig, 
    /**
     * graphql extension.
     */
    graphql: GraphqlMain, 
    /**
     * slot registry of ui roots.
     */
    uiRootSlot: UIRootRegistry, 
    /**
     * express extension.
     */
    express: ExpressMain, 
    /**
     * on start slot
     */
    onStartSlot: OnStartSlot, 
    /**
     * component extension.
     */
    componentExtension: ComponentMain, 
    /**
     * ui logger instance.
     */
    cache: CacheMain, 
    /**
     * ui logger instance.
     */
    logger: Logger);
    /**
     * create a build of the given UI root.
     */
    build(uiRootName?: string): Promise<any>;
    /**
     * create a Bit UI runtime.
     */
    createRuntime({ uiRootName, pattern, dev, port, rebuild }: RuntimeOptions): Promise<UIServer>;
    getPort(port?: number): Promise<number>;
    /**
     * bind to ui server start event.
     */
    registerOnStart(onStartFn: OnStart): this;
    private invokeOnStart;
    /**
     * register a UI slot.
     */
    registerUiRoot(uiRoot: UIRoot): void;
    /**
     * get a UI runtime instance.
     */
    getUi(uiRootName?: string): [string, UIRoot];
    getUiRootOrThrow(uiRootName: string): UIRoot;
    createLink(aspectDefs: AspectDefinition[], rootExtensionName: string): Promise<string>;
    /**
     * generate the root file of the UI runtime.
     */
    generateRoot(aspectDefs: AspectDefinition[], rootExtensionName: string, runtimeName?: string, rootAspect?: string): Promise<string>;
    private selectPort;
    private buildUiHash;
    private buildIfChanged;
    private openBrowser;
    static defaultConfig: {
        portRange: number[];
        host: string;
    };
    static runtime: import("@teambit/harmony").RuntimeDefinition;
    static dependencies: import("@teambit/harmony").Aspect[];
    static slots: (((registerFn: () => string) => SlotRegistry<UIRoot>) | ((registerFn: () => string) => SlotRegistry<OnStart>))[];
    static provider([cli, graphql, express, componentExtension, cache, loggerMain]: UIDeps, config: any, [uiRootSlot, onStartSlot]: [UIRootRegistry, OnStartSlot]): Promise<UiMain>;
}
